# this is new spider framework gerridae

> 学习之作, 参考[ruia](https://github.com/howie6879/ruia)


## 安装

- 使用pip安装

```bash
pip install gerridae --user
```

- 使用pipenv安装

```bash
pipenv install gerridae
```

- 使用源码安装

```bash
git clone https://github.com/BUGLAN/gerridae

python setup.py install
```

## 测试

- 安装测试依赖包

```bash
pipenv install --dev
```

- 执行测试

```bash
pipenv run pytest
```

## 额外说明

基本是一个学习之作, 可以说一个简单的玩具, 请勿使用在生产环境之中

